@@ -1,5 +1,7 @@
 #include <Rinternals.h>
 
+SEXP c_caps_f(SEXP y, SEXP n, SEXP stiffness, SEXP pct, SEXP res);
+SEXP c_ads_f(SEXP y, SEXP n, SEXP stiffness, SEXP res);
 SEXP exactmean(SEXP x);
 SEXP gini(SEXP x);
 SEXP makear1(SEXP t, SEXP np, SEXP tau);
